#include "tao/ZIOP_Adapter.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_ZIOP_Adapter::~TAO_ZIOP_Adapter ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
